/* eslint-disable react/prop-types */
import React, { useCallback, useEffect, useRef, useState } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import Chevronbottom from '@schibstedspain/sui-svgiconset/lib/Chevronbottom';
var BASE_CLASS = 'sui-DropdownBasic';
var MENU_CLASS = BASE_CLASS + "Menu";

var NO_OP = function NO_OP() {};

var defaultLinkFactory = function defaultLinkFactory(_ref) {
  var href = _ref.href,
      className = _ref.className,
      children = _ref.children,
      onClick = _ref.onClick,
      rel = _ref.rel,
      target = _ref.target,
      title = _ref.title;
  return React.createElement("a", {
    href: href,
    className: className,
    onClick: onClick,
    rel: rel || undefined,
    target: target,
    title: title
  }, children);
};
/**
 * Dropdown menu containing sections of links, triggered from a simple button
 * with an optional icon.
 */


export default function DropdownBasic(_ref2) {
  var button = _ref2.button,
      _ref2$closeOnDocument = _ref2.closeOnDocumentClick,
      closeOnDocumentClick = _ref2$closeOnDocument === void 0 ? false : _ref2$closeOnDocument,
      _ref2$closeOnItemClic = _ref2.closeOnItemClick,
      closeOnItemClick = _ref2$closeOnItemClic === void 0 ? false : _ref2$closeOnItemClic,
      _ref2$expandOnMouseOv = _ref2.expandOnMouseOver,
      expandOnMouseOver = _ref2$expandOnMouseOv === void 0 ? false : _ref2$expandOnMouseOv,
      _ref2$linkFactory = _ref2.linkFactory,
      linkFactory = _ref2$linkFactory === void 0 ? defaultLinkFactory : _ref2$linkFactory,
      menu = _ref2.menu;

  var _useState = useState(false),
      expanded = _useState[0],
      setExpanded = _useState[1];

  var _useState2 = useState(false),
      collapseByTouch = _useState2[0],
      setCollapseByTouch = _useState2[1];

  var wrapper = useRef(null);
  var toggleMenu = useCallback(function (expand) {
    var newExpanded = typeof expand !== 'undefined' ? expand : !expanded;
    setExpanded(newExpanded);
  }, [expanded]);
  useEffect(function () {
    var handleListener = function handleListener(add) {
      var listenerMethod = add ? 'addEventListener' : 'removeEventListener';
      document[listenerMethod]('click', onDocumentClick, false);
    };

    var onDocumentClick = function onDocumentClick(event) {
      var target = event.target;
      var isClickOutsideDropdown = !wrapper.current.contains(target);
      isClickOutsideDropdown && closeOnDocumentClick && toggleMenu(false);
    };

    handleListener(expanded);
    return function () {
      return handleListener(false);
    };
  }, [expanded, closeOnDocumentClick, toggleMenu]);

  var onClick = function onClick(e) {
    toggleMenu();
  };
  /**
   * Mouse over event handler.
   */


  var onMouseOver = function onMouseOver() {
    setExpanded(true);
    setCollapseByTouch(true);
  };
  /**
   * Mouse out event handler.
   */


  var onMouseOut = function onMouseOut() {
    setExpanded(false);
    setCollapseByTouch(false);
  };
  /**
   * Function rendering menu element.
   */


  var renderMenuItem = function renderMenuItem(_ref3, index) {
    var title = _ref3.title,
        links = _ref3.links;
    return React.createElement("div", {
      key: index,
      className: MENU_CLASS + "-item"
    }, title && React.createElement("header", {
      className: MENU_CLASS + "-title"
    }, title), React.createElement("ul", {
      className: MENU_CLASS + "-list"
    }, links.map(renderLink)));
  };
  /**
   * Function rendering a simple list item link.
   */


  var renderLink = function renderLink(_ref4, index) {
    var onClick = _ref4.onClick,
        rel = _ref4.rel,
        target = _ref4.target,
        text = _ref4.text,
        url = _ref4.url;
    var Link = linkFactory;

    var onClickHandler = function onClickHandler(e) {
      onClick && onClick(e);
      closeOnItemClick && toggleMenu(false);
    };

    return React.createElement("li", {
      key: index,
      className: MENU_CLASS + "-listItem"
    }, React.createElement(Link, {
      href: url,
      className: MENU_CLASS + "-listLink",
      onClick: onClickHandler,
      rel: rel || undefined,
      target: target,
      title: text
    }, text));
  };

  var text = button.text,
      Icon = button.icon;
  var ArrowButtonIcon = button.arrowButtonIcon || Chevronbottom;
  var wrapperClassName = cx(BASE_CLASS, {
    'is-expanded': expanded
  });
  return React.createElement("div", {
    className: wrapperClassName,
    onMouseOver: expandOnMouseOver ? onMouseOver : NO_OP,
    onMouseOut: expandOnMouseOver ? onMouseOut : NO_OP
  }, React.createElement("div", {
    className: BASE_CLASS + "-buttonWrap"
  }, React.createElement("button", {
    className: BASE_CLASS + "-button",
    onClick: expandOnMouseOver ? NO_OP : onClick,
    onTouchStart: expandOnMouseOver && collapseByTouch ? onClick : NO_OP
  }, React.createElement("div", {
    className: BASE_CLASS + "-buttonContent"
  }, Icon && React.createElement(Icon, {
    svgClass: BASE_CLASS + "-buttonIcon"
  }), React.createElement("span", null, text)), React.createElement(ArrowButtonIcon, {
    svgClass: BASE_CLASS + "-buttonIcon"
  }))), React.createElement("div", {
    className: MENU_CLASS,
    ref: wrapper
  }, menu.map(renderMenuItem)));
}
DropdownBasic.displayName = 'DropdownBasic';